% LTFAT - Computational subroutines.
%
%   Peter L. Soendergaard, 2007.
%
%   This page documents the computational subroutines.
%
%   The subroutines are not meant to be called directly.
%   They do not verify the input parameters in any way,
%   and may require you to supply them with precomputed
%   input from other routines.
%
%   They all take a fixed number of input and output arguments.
%
%   A computational function may only call other computational functions,
%   but never any of the interface functions or assertion routines.
%
%   Gabor transforms.
%     COMP_DGT             - DGT
%     COMP_DGT_FB          - Filter bank DGT
%     COMP_IDGT            - IDGT
%     COMP_IDGT_FB         - Filter bank IDGT
%     COMP_WFAC            - Window factorization.
%     COMP_IWFAC           - Inverse window factorization.
%
%   Gabor frame operator.
%     COMP_CANDUAL_FAC     - Factorization of canonical dual window.
%     COMP_CANTIGHT_FAC    - Factorization of canonical tight window.
%     COMP_GFEIGS          - Eigenvalues of frameop.
%
%   Wilson systems.
%     COMP_DWILT           - Discrete Wilson Transform
%     COMP_IDWILT          - Inverse Discrete Wilson Transform.
%
%   Windows.
%     COMP_PGAUSS          - Discrete Gaussian.
%
%   Helper function
%     POSTPAD              - Pad/truncate end of sequency.
%     POSTPAD2             - As above for matrices.
%
%   For help, errors, suggestions etc. please send email to
%   ltfat-help@lists.sourceforge.net

% This program is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% You should have received a copy of the GNU General Public License
% along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
