function c=comp_dgt(f,g,a,M,L,wilson,callfun)
%COMP_DGT  Compute a DGT
%   Usage:  c=comp_dgt(f,g,a,M,L);
%
%   Input parameters:
%         f     : Input data
%         g     : Window function.
%         a     : Length of time shift.
%         M     : Number of modulations.
%         L     : Length of transform to do.
%   Output parameters:
%         c     : M*N array of coefficients.
%

% This program is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% You should have received a copy of the GNU General Public License
% along with this program.  If not, see <http://www.gnu.org/licenses/>.

%   AUTHOR : Peter Soendergaard.

Lwindow=size(g,1);

W=size(f,2);
N=L/a;

if Lwindow<L
  % Do the filter bank algorithm
  % Periodic boundary conditions
  c=comp_dgt_fb(f,g,a,M,0);

else
  % Do the factorization algorithm
  
  N=L/a;
  W=size(f,2);

  % Get the factorization of the window.
  gf=comp_wfac(g,a,M);
  
  % Compute the window application and the DFT modulation.
  c=fft(comp_dgt_fac(f,gf,a,M))/sqrt(M);
  
end;

c=reshape(c,M,N,W);


